@@ -217,8 +217,8 @@ ExtremeAnom <- function(x, dates, h, refp, anop, rge, output = "both", rfd = 0.9
   
   na.sta <- first.no.NA.DOY-1
   na.end <- last.no.NA.DOY+1
-  h2d$cumDensity[1:na.sta,] <- NA
-  h2d$cumDensity[na.end:365,] <- NA
+  if(na.sta>=1) {h2d$cumDensity[1:na.sta,] <- NA}
+  if(na.end<=365) {h2d$cumDensity[na.end:365,] <- NA}
 
   if (h == 2) {
     for (i in 1:nrow(D2)) {
